hyperfiddle.rcf.reporters


*block-state*clj

source

*reporter-key*clj/s

source (clj)source (cljs)

compact-reporterclj/s

source (clj)source (cljs)

dopamine-reporterclj/s

source (clj)source (cljs)

list-reportersclj/s

(list-reporters)
source (clj)source (cljs)

register-reporter!clj/s

(register-reporter! k r)
source (clj)source (cljs)

reporter-registryclj/s

source (clj)source (cljs)

set-reporter!clj/s

(set-reporter! k)
source (clj)source (cljs)

testing-vars-strcljs

(testing-vars-str m)

Returns a string representation of the current test. Renders names in testing-vars as a list, then the source file and line of current assertion.

Returns a string representation of the current test.  Renders names
in *testing-vars* as a list, then the source file and line of
current assertion.
sourceraw docstring

with-reporterclj/smacro

(with-reporter k & body)
source

cljdoc builds & hosts documentation for Clojure/Script libraries